Core Seal Developer's Guide

# Introduction

This manual describes the implementation and source-code organization of Seal, for those who might wish to modify it.

## Use

### Environment

In this chapter, the source directory for Seal is referred to as `$SEAL`. It is created by unpacking a tar file or by cloning from the git repository, and is usually named `seal` or `seal-x.x.x`. It has the following toplevel listing:

    Makefile      cx          doc          python
    configure     data        examples     scripts

The directory into which Seal is installed is referred to as `$DEST`. By default it is the same as `$SEAL`, but it can specified by passing `--prefix=dir` to the `configure` script.

The examples assume the following environment variable settings:

- `PATH` includes `$DEST/bin`
- `PYTHONPATH` includes `$DEST/python`

The python examples assume that one has done:

    >>> import seal

A first test:

    >>> seal.hello()
    Hello.  This is Seal ...

The actual output will have the version number in place of ... .

### Installation

The "pure Python" subset of Seal requires no installation. One only needs to assure that `$SEAL/python` is included on one's `PYTHONPATH`.

For full functionality, go to the `$SEAL` directory and do:

    $ ./configure
    $ make

Installation in an external directory is not necessary, provided that `$SEAL/python` is included on `PYTHONPATH`. If installation in an external directory is desired, one may specify it when calling `configure`:

    $ ./configure --prefix=/usr/local
    $ make
    $ make install